@@ -3,6 +3,7 @@ import uuid
 import paypalrestsdk.util as util
 from paypalrestsdk.api import default as default_api
 
+
 class Resource(object):
     """Base class for all REST services
     """
@@ -25,7 +26,7 @@ class Resource(object):
         if self.request_id is None:
             self.request_id = str(uuid.uuid4())
         return self.request_id
- 
+
     def http_headers(self):
         """Generate HTTP header
         """
@@ -55,7 +56,7 @@ class Resource(object):
     def merge(self, new_attributes):
         """Merge new attributes e.g. response from a post to Resource
         """
-        for k,v in new_attributes.items():
+        for k, v in new_attributes.items():
             setattr(self, k, v)
 
     def convert(self, name, value):
@@ -122,7 +123,7 @@ class List(Resource):
         https://developer.paypal.com/docs/api/#list-payment-resources
 
         Usage::
-            
+
             >>> payment_histroy = Payment.all({'count': 2})
         """
         api = api or default_api()
@@ -136,15 +137,25 @@ class List(Resource):
 
 class Create(Resource):
 
-    def create(self):
+    def create(self, refresh_token=None, correlation_id=None):
         """Creates a resource e.g. payment
 
         Usage::
 
             >>> payment = Payment({})
-            >>> payment.create() # return True or False     
+            >>> payment.create() # return True or False
         """
-        new_attributes = self.api.post(self.path, self.to_dict(), self.http_headers())
+
+        headers = {}
+        if correlation_id is not None:
+            headers = util.merge_dict(
+                self.http_headers(),
+                {'Paypal-Application-Correlation-Id': correlation_id}
+            )
+        else:
+            headers = self.http_headers()
+
+        new_attributes = self.api.post(self.path, self.to_dict(), headers, refresh_token)
         self.error = None
         self.merge(new_attributes)
         return self.success()
@@ -165,6 +176,7 @@ class Delete(Resource):
         self.merge(new_attributes)
         return self.success()
 
+
 class Post(Resource):
 
     def post(self, name, attributes=None, cls=Resource):
@@ -187,4 +199,3 @@ class Post(Resource):
             return self.success()
         else:
             return cls(new_attributes, api=self.api)
-
